@@ -7,5 +7,5 @@ Created by Michael Smith on 2012-06-21.
 Copyright © 2012 True Action Network. All rights reserved.
 """
 
-from mongo_file import MongoFile
-__all__ = ["MongoFile"]
+from mongo_file import exists, MongoFile, remove, rename
+__all__ = ["exists", "MongoFile", "remove", "rename"]
