@@ -98,7 +98,7 @@ class MongoFile(RawIOBase):
 		self.collection.insert({
 			"name": self.name,
 			"data": buf,
-		})
+		}, safe=True)
 		return buf
 	@property
 	def _spec(self):
@@ -163,7 +163,7 @@ class MongoFile(RawIOBase):
 			self.collection.insert({
 				"name": self.name,
 				"data": buf,
-			})
+			}, safe=True)
 		else:
 			raise IOError("MongoFile '%s' is not writable." % self.name)
 		return 0
@@ -177,7 +177,7 @@ class MongoFile(RawIOBase):
 			self.collection.insert({
 				"name": self.name,
 				"data": data,
-			})
+			}, safe=True)
 		else:
 			raise IOError("MongoFile '%s' is not writable." % self.name)
 		return size
