@@ -9,6 +9,7 @@ Copyright © 2012 True Action Network. All rights reserved.
 
 from . import exists, MongoFile, remove, rename
 from contextlib import closing
+from csv import writer
 from mongo_file import valid_name
 from os import chdir, getcwdu
 from pymongo import Connection
@@ -19,7 +20,11 @@ from unittest import TestCase
 DATA = """Four score and seven years ago our fathers brought forth
 upon this continent, a new nation, conceived in Liberty, and
 dedicated to the proposition that all men are created equal."""
-CSV_DATA = [row.split() for row in DATA.split('\n')]
+CSV_DATA = (
+	(u'2012-07-02T04:02:48+00:00', '', '', u'cs_svanbrug', u'100000238', '53', u'1113', '', '', '', '', 'Webstore', '', u'1.0', u'599.99', u'6.66666666667', u'49.5', '599.99', '', '', ''),
+	(u'2012-07-02T04:02:48+00:00', '', '', u'cs_svanbrug', u'100000238', '51', u'1111', '', '', '', '', 'Webstore', '', u'2.0', u'599.98', u'6.66666666667', u'49.5', '599.98', '', '', ''),
+	(u'2012-07-02T04:02:48+00:00', '', '', u'cs_svanbrug', u'100000238', '52', u'1112', '', '', '', '', 'Webstore', '', u'1.0', u'129.99', u'6.66666666667', u'10.72', '129.99', '', '', ''),
+)
 DB_ARGS = {
 	"collection_name": "test",
 	"db_name": "test",
@@ -61,6 +66,15 @@ class MongoFileTest(TestCase):
 		mfile.close()
 		self.assertTrue(mfile.closed, mfile.closed)
 		self.assertRaises(IOError, mfile.read)
+	def test_csv_writelines(self):
+		"""Test that csv.writelines works the same with a mongofile and a file."""
+		with open("empty", mode="w") as csvfile:
+			csvwriter = writer(csvfile)
+			csvwriter.writerows(CSV_DATA)
+		with MongoFile("empty", mode="w", **DB_ARGS) as csvfile:
+			csvwriter = writer(csvfile)
+			csvwriter.writerows(CSV_DATA)
+		self.assertEqual(open("empty").read(), MongoFile("empty", **DB_ARGS).read())
 	def test_exists(self):
 		"""
 		Test that a mongo file exists when you know it exists
